# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.18.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1Disk(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'device': 'str',
        'partitions': 'list[V1DiskPartition]',
        'wipeonreinstall': 'bool'
    }

    attribute_map = {
        'device': 'device',
        'partitions': 'partitions',
        'wipeonreinstall': 'wipeonreinstall'
    }

    def __init__(self, device=None, partitions=None, wipeonreinstall=None):  # noqa: E501
        """V1Disk - a model defined in Swagger"""  # noqa: E501

        self._device = None
        self._partitions = None
        self._wipeonreinstall = None
        self.discriminator = None

        self.device = device
        if partitions is not None:
            self.partitions = partitions
        self.wipeonreinstall = wipeonreinstall

    @property
    def device(self):
        """Gets the device of this V1Disk.  # noqa: E501

        the device to create the partitions  # noqa: E501

        :return: The device of this V1Disk.  # noqa: E501
        :rtype: str
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this V1Disk.

        the device to create the partitions  # noqa: E501

        :param device: The device of this V1Disk.  # noqa: E501
        :type: str
        """
        if device is None:
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    @property
    def partitions(self):
        """Gets the partitions of this V1Disk.  # noqa: E501

        list of partitions to create on this disk  # noqa: E501

        :return: The partitions of this V1Disk.  # noqa: E501
        :rtype: list[V1DiskPartition]
        """
        return self._partitions

    @partitions.setter
    def partitions(self, partitions):
        """Sets the partitions of this V1Disk.

        list of partitions to create on this disk  # noqa: E501

        :param partitions: The partitions of this V1Disk.  # noqa: E501
        :type: list[V1DiskPartition]
        """

        self._partitions = partitions

    @property
    def wipeonreinstall(self):
        """Gets the wipeonreinstall of this V1Disk.  # noqa: E501

        if set to true, this disk will be wiped before reinstallation  # noqa: E501

        :return: The wipeonreinstall of this V1Disk.  # noqa: E501
        :rtype: bool
        """
        return self._wipeonreinstall

    @wipeonreinstall.setter
    def wipeonreinstall(self, wipeonreinstall):
        """Sets the wipeonreinstall of this V1Disk.

        if set to true, this disk will be wiped before reinstallation  # noqa: E501

        :param wipeonreinstall: The wipeonreinstall of this V1Disk.  # noqa: E501
        :type: bool
        """
        if wipeonreinstall is None:
            raise ValueError("Invalid value for `wipeonreinstall`, must not be `None`")  # noqa: E501

        self._wipeonreinstall = wipeonreinstall

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Disk, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Disk):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.18.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1ImageBase(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'classification': 'str',
        'expiration_date': 'datetime',
        'features': 'list[str]',
        'url': 'str',
        'usedby': 'list[str]'
    }

    attribute_map = {
        'classification': 'classification',
        'expiration_date': 'expirationDate',
        'features': 'features',
        'url': 'url',
        'usedby': 'usedby'
    }

    def __init__(self, classification=None, expiration_date=None, features=None, url=None, usedby=None):  # noqa: E501
        """V1ImageBase - a model defined in Swagger"""  # noqa: E501

        self._classification = None
        self._expiration_date = None
        self._features = None
        self._url = None
        self._usedby = None
        self.discriminator = None

        if classification is not None:
            self.classification = classification
        self.expiration_date = expiration_date
        if features is not None:
            self.features = features
        if url is not None:
            self.url = url
        if usedby is not None:
            self.usedby = usedby

    @property
    def classification(self):
        """Gets the classification of this V1ImageBase.  # noqa: E501

        classification of this image  # noqa: E501

        :return: The classification of this V1ImageBase.  # noqa: E501
        :rtype: str
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        """Sets the classification of this V1ImageBase.

        classification of this image  # noqa: E501

        :param classification: The classification of this V1ImageBase.  # noqa: E501
        :type: str
        """

        self._classification = classification

    @property
    def expiration_date(self):
        """Gets the expiration_date of this V1ImageBase.  # noqa: E501

        expirationDate of this image  # noqa: E501

        :return: The expiration_date of this V1ImageBase.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this V1ImageBase.

        expirationDate of this image  # noqa: E501

        :param expiration_date: The expiration_date of this V1ImageBase.  # noqa: E501
        :type: datetime
        """
        if expiration_date is None:
            raise ValueError("Invalid value for `expiration_date`, must not be `None`")  # noqa: E501

        self._expiration_date = expiration_date

    @property
    def features(self):
        """Gets the features of this V1ImageBase.  # noqa: E501

        features of this image  # noqa: E501

        :return: The features of this V1ImageBase.  # noqa: E501
        :rtype: list[str]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this V1ImageBase.

        features of this image  # noqa: E501

        :param features: The features of this V1ImageBase.  # noqa: E501
        :type: list[str]
        """

        self._features = features

    @property
    def url(self):
        """Gets the url of this V1ImageBase.  # noqa: E501

        the url of this image  # noqa: E501

        :return: The url of this V1ImageBase.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this V1ImageBase.

        the url of this image  # noqa: E501

        :param url: The url of this V1ImageBase.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def usedby(self):
        """Gets the usedby of this V1ImageBase.  # noqa: E501

        machines where this image is in use  # noqa: E501

        :return: The usedby of this V1ImageBase.  # noqa: E501
        :rtype: list[str]
        """
        return self._usedby

    @usedby.setter
    def usedby(self, usedby):
        """Sets the usedby of this V1ImageBase.

        machines where this image is in use  # noqa: E501

        :param usedby: The usedby of this V1ImageBase.  # noqa: E501
        :type: list[str]
        """

        self._usedby = usedby

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ImageBase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ImageBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.18.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.filesystemlayout_api import FilesystemlayoutApi  # noqa: E501
from metal_python.rest import ApiException


class TestFilesystemlayoutApi(unittest.TestCase):
    """FilesystemlayoutApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.filesystemlayout_api.FilesystemlayoutApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_filesystem_layout(self):
        """Test case for create_filesystem_layout

        create a filesystemlayout. if the given ID already exists a conflict is returned  # noqa: E501
        """
        pass

    def test_delete_filesystem_layout(self):
        """Test case for delete_filesystem_layout

        deletes an filesystemlayout and returns the deleted entity  # noqa: E501
        """
        pass

    def test_get_filesystem_layout(self):
        """Test case for get_filesystem_layout

        get filesystemlayout by id  # noqa: E501
        """
        pass

    def test_list_filesystem_layouts(self):
        """Test case for list_filesystem_layouts

        get all filesystemlayouts  # noqa: E501
        """
        pass

    def test_match_filesystem_layout(self):
        """Test case for match_filesystem_layout

        check if the given machine id satisfies the disk requirements of the filesystemlayout in question  # noqa: E501
        """
        pass

    def test_try_filesystem_layout(self):
        """Test case for try_filesystem_layout

        try to detect a filesystemlayout based on given size and image.  # noqa: E501
        """
        pass

    def test_update_filesystem_layout(self):
        """Test case for update_filesystem_layout

        updates a filesystemlayout. if the filesystemlayout was changed since this one was read, a conflict is returned  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.18.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1Raid(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'arrayname': 'str',
        'createoptions': 'list[str]',
        'devices': 'list[str]',
        'level': 'str',
        'spares': 'int'
    }

    attribute_map = {
        'arrayname': 'arrayname',
        'createoptions': 'createoptions',
        'devices': 'devices',
        'level': 'level',
        'spares': 'spares'
    }

    def __init__(self, arrayname=None, createoptions=None, devices=None, level=None, spares=None):  # noqa: E501
        """V1Raid - a model defined in Swagger"""  # noqa: E501

        self._arrayname = None
        self._createoptions = None
        self._devices = None
        self._level = None
        self._spares = None
        self.discriminator = None

        self.arrayname = arrayname
        if createoptions is not None:
            self.createoptions = createoptions
        if devices is not None:
            self.devices = devices
        self.level = level
        self.spares = spares

    @property
    def arrayname(self):
        """Gets the arrayname of this V1Raid.  # noqa: E501

        the name of the resulting array device  # noqa: E501

        :return: The arrayname of this V1Raid.  # noqa: E501
        :rtype: str
        """
        return self._arrayname

    @arrayname.setter
    def arrayname(self, arrayname):
        """Sets the arrayname of this V1Raid.

        the name of the resulting array device  # noqa: E501

        :param arrayname: The arrayname of this V1Raid.  # noqa: E501
        :type: str
        """
        if arrayname is None:
            raise ValueError("Invalid value for `arrayname`, must not be `None`")  # noqa: E501

        self._arrayname = arrayname

    @property
    def createoptions(self):
        """Gets the createoptions of this V1Raid.  # noqa: E501

        the options to use to create the raid array  # noqa: E501

        :return: The createoptions of this V1Raid.  # noqa: E501
        :rtype: list[str]
        """
        return self._createoptions

    @createoptions.setter
    def createoptions(self, createoptions):
        """Sets the createoptions of this V1Raid.

        the options to use to create the raid array  # noqa: E501

        :param createoptions: The createoptions of this V1Raid.  # noqa: E501
        :type: list[str]
        """

        self._createoptions = createoptions

    @property
    def devices(self):
        """Gets the devices of this V1Raid.  # noqa: E501

        list of devices to form the raid array from  # noqa: E501

        :return: The devices of this V1Raid.  # noqa: E501
        :rtype: list[str]
        """
        return self._devices

    @devices.setter
    def devices(self, devices):
        """Sets the devices of this V1Raid.

        list of devices to form the raid array from  # noqa: E501

        :param devices: The devices of this V1Raid.  # noqa: E501
        :type: list[str]
        """

        self._devices = devices

    @property
    def level(self):
        """Gets the level of this V1Raid.  # noqa: E501

        raid level to create, should be 0 or 1  # noqa: E501

        :return: The level of this V1Raid.  # noqa: E501
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this V1Raid.

        raid level to create, should be 0 or 1  # noqa: E501

        :param level: The level of this V1Raid.  # noqa: E501
        :type: str
        """
        if level is None:
            raise ValueError("Invalid value for `level`, must not be `None`")  # noqa: E501

        self._level = level

    @property
    def spares(self):
        """Gets the spares of this V1Raid.  # noqa: E501

        number of spares for the raid array  # noqa: E501

        :return: The spares of this V1Raid.  # noqa: E501
        :rtype: int
        """
        return self._spares

    @spares.setter
    def spares(self, spares):
        """Sets the spares of this V1Raid.

        number of spares for the raid array  # noqa: E501

        :param spares: The spares of this V1Raid.  # noqa: E501
        :type: int
        """
        if spares is None:
            raise ValueError("Invalid value for `spares`, must not be `None`")  # noqa: E501

        self._spares = spares

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Raid, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Raid):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.18.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineIpmiReport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bios_version': 'str',
        'bmc_ip': 'str',
        'bmc_version': 'str',
        'fru': 'V1MachineFru',
        'power_state': 'str'
    }

    attribute_map = {
        'bios_version': 'BIOSVersion',
        'bmc_ip': 'BMCIp',
        'bmc_version': 'BMCVersion',
        'fru': 'FRU',
        'power_state': 'PowerState'
    }

    def __init__(self, bios_version=None, bmc_ip=None, bmc_version=None, fru=None, power_state=None):  # noqa: E501
        """V1MachineIpmiReport - a model defined in Swagger"""  # noqa: E501

        self._bios_version = None
        self._bmc_ip = None
        self._bmc_version = None
        self._fru = None
        self._power_state = None
        self.discriminator = None

        self.bios_version = bios_version
        self.bmc_ip = bmc_ip
        self.bmc_version = bmc_version
        self.fru = fru
        self.power_state = power_state

    @property
    def bios_version(self):
        """Gets the bios_version of this V1MachineIpmiReport.  # noqa: E501


        :return: The bios_version of this V1MachineIpmiReport.  # noqa: E501
        :rtype: str
        """
        return self._bios_version

    @bios_version.setter
    def bios_version(self, bios_version):
        """Sets the bios_version of this V1MachineIpmiReport.


        :param bios_version: The bios_version of this V1MachineIpmiReport.  # noqa: E501
        :type: str
        """
        if bios_version is None:
            raise ValueError("Invalid value for `bios_version`, must not be `None`")  # noqa: E501

        self._bios_version = bios_version

    @property
    def bmc_ip(self):
        """Gets the bmc_ip of this V1MachineIpmiReport.  # noqa: E501


        :return: The bmc_ip of this V1MachineIpmiReport.  # noqa: E501
        :rtype: str
        """
        return self._bmc_ip

    @bmc_ip.setter
    def bmc_ip(self, bmc_ip):
        """Sets the bmc_ip of this V1MachineIpmiReport.


        :param bmc_ip: The bmc_ip of this V1MachineIpmiReport.  # noqa: E501
        :type: str
        """
        if bmc_ip is None:
            raise ValueError("Invalid value for `bmc_ip`, must not be `None`")  # noqa: E501

        self._bmc_ip = bmc_ip

    @property
    def bmc_version(self):
        """Gets the bmc_version of this V1MachineIpmiReport.  # noqa: E501


        :return: The bmc_version of this V1MachineIpmiReport.  # noqa: E501
        :rtype: str
        """
        return self._bmc_version

    @bmc_version.setter
    def bmc_version(self, bmc_version):
        """Sets the bmc_version of this V1MachineIpmiReport.


        :param bmc_version: The bmc_version of this V1MachineIpmiReport.  # noqa: E501
        :type: str
        """
        if bmc_version is None:
            raise ValueError("Invalid value for `bmc_version`, must not be `None`")  # noqa: E501

        self._bmc_version = bmc_version

    @property
    def fru(self):
        """Gets the fru of this V1MachineIpmiReport.  # noqa: E501


        :return: The fru of this V1MachineIpmiReport.  # noqa: E501
        :rtype: V1MachineFru
        """
        return self._fru

    @fru.setter
    def fru(self, fru):
        """Sets the fru of this V1MachineIpmiReport.


        :param fru: The fru of this V1MachineIpmiReport.  # noqa: E501
        :type: V1MachineFru
        """
        if fru is None:
            raise ValueError("Invalid value for `fru`, must not be `None`")  # noqa: E501

        self._fru = fru

    @property
    def power_state(self):
        """Gets the power_state of this V1MachineIpmiReport.  # noqa: E501


        :return: The power_state of this V1MachineIpmiReport.  # noqa: E501
        :rtype: str
        """
        return self._power_state

    @power_state.setter
    def power_state(self, power_state):
        """Sets the power_state of this V1MachineIpmiReport.


        :param power_state: The power_state of this V1MachineIpmiReport.  # noqa: E501
        :type: str
        """
        if power_state is None:
            raise ValueError("Invalid value for `power_state`, must not be `None`")  # noqa: E501

        self._power_state = power_state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineIpmiReport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineIpmiReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
